@@ -1,20 +1,20 @@
 /**********************************************************************************************
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-
+    
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
+    
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
+#include "config.h"
 
 #ifdef _MSC_VER
 #define fseeko _fseeki64
@@ -420,14 +420,20 @@ static uint32_t scale2jnx(double scale)
 static char randChar()
 {
     char buf[2];
+#if defined(HAVE_ARC4RANDOM)
+    int r = (int)((arc4random() * 16.0) / UINT_MAX);
+#else
     int r = (int)((rand() * 16.0) / RAND_MAX);
+#endif
     sprintf(buf,"%X", r & 0x0F);
     return buf[0];
 }
 
 static void createGUID(char * guid)
 {
+#if !defined(HAVE_ARC4RANDOM)
     srand((unsigned int)time(0));
+#endif
 
     guid[0]     = randChar();
     guid[1]     = randChar();
