@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2007 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 #include "CResources.h"
@@ -65,8 +64,8 @@
 #include <stdio.h>
 #include <tzdata.h>
 
-QPen CCanvas::penBorderBlue(QColor(10,10,150,220),3);
-QPen CCanvas::penBorderBlack(QColor(0,0,0,200),3);
+QPen CCanvas::penBorderBlue(QColor(10,10,150,220),2);
+QPen CCanvas::penBorderBlack(QColor(0,0,0,200),2);
 QBrush CCanvas::brushBackWhite(QColor(255,255,255,210));
 QBrush CCanvas::brushBackYellow(QColor(0xff, 0xff, 0xcc, 0xE0));
 
@@ -290,15 +289,21 @@ void CCanvas::mouseMoveEvent(QMouseEvent * e)
 
 void CCanvas::mousePressEvent(QMouseEvent * e)
 {
-    posMouse = e->pos();
-    mouse->mousePressEvent(e);
+    if (!contextMenuActive)
+    {
+        posMouse = e->pos();
+        mouse->mousePressEvent(e);
+    }
 }
 
 
 void CCanvas::mouseReleaseEvent(QMouseEvent * e)
 {
-    posMouse = e->pos();
-    mouse->mouseReleaseEvent(e);
+    if (!contextMenuActive)
+    {
+        posMouse = e->pos();
+        mouse->mouseReleaseEvent(e);
+    }
 }
 
 
@@ -332,7 +337,10 @@ void CCanvas::leaveEvent(QEvent * )
 {
     QApplication::restoreOverrideCursor();
     setMouseTracking(false);
-    if (mouse) mouse->setSelTrackPt(0);
+    if(mouse && !contextMenuActive)
+    {
+        mouse->setSelTrackPt(0);
+    }
 }
 
 
@@ -868,12 +876,12 @@ void CCanvas::raiseContextMenu(const QPoint& pos)
     //    menu.addAction(QIcon(":/icons/iconClipboard16x16.png"),tr("Copy Position"),this,SLOT(slotCopyPosition()));
     mouse->contextMenu(menu);
 
+    contextMenuActive = true;
     QPoint p = mapToGlobal(pos);
     setMouseTracking(false);
-    contextMenuActive = true;
     menu.exec(p);
-    contextMenuActive = false;
     setMouseTracking(true);
+    contextMenuActive = false;
 }
 
 
@@ -904,6 +912,7 @@ void CCanvas::slotPointOfFocus(const int idx)
     {
         if(idx < 0)
         {
+            mouseMoveMap->setSelTrackPt(0);
             return;
         }
         mouseMoveMap->setSelTrackPt(&trkpts[idx]);
