@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2007 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -70,6 +69,7 @@ CDlgEditWpt::CDlgEditWpt(CWpt &wpt, QWidget * parent)
         toolIcon->setEnabled(false);
         lineName->setEnabled(false);
         linePosition->setEnabled(false);
+        tabWidget->setCurrentIndex(1);
     }
 
 #ifdef HAS_DMTX
@@ -327,12 +327,8 @@ void CDlgEditWpt::accept()
         CWptDB::self().addWpt(wpt2,false);
     }
 
-    //    wpt.geocache.exportBuddies = checkExportBuddies->isChecked();
-
     wpt.parentWpt = comboParentWpt->currentText();
 
-    emit CWptDB::self().sigChanged();
-    emit CWptDB::self().sigModified();
     emit CWptDB::self().sigModified(wpt.getKey());
 
     if(wpt.getName() != name)
