@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2010 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 #ifndef CGEODB_H
@@ -136,13 +135,13 @@ class CGeoDB : public QWidget, private Ui::IGeoToolWidget
         /// move database from one version to most resent version
         void migrateDB(int version);
         /// call each time the workspace changed
-        void changedWorkspace();
+        void changedWorkspace(quint32 what);
         /// update the item text in workspace with a "*" for chnaged items
-        void updateModifyMarker();
+        void updateModifyMarker(quint32 what);
         /// update the item text in workspace with a "*" for chnaged items
         void updateModifyMarker(QTreeWidgetItem * item, QSet<QString>& keys, const QString& label);
         /// update "in database" icon
-        void updateDatabaseMarker();
+        void updateDatabaseMarker(quint32 what);
         /// update "in database" icon
         void updateDatabaseMarker(QTreeWidgetItem * itemWks, QSet<quint64> &keysWks);
         /// initialize database treewidget on startup
