@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2008 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -701,6 +700,7 @@ CTrack::CTrack(QObject * parent)
     connect(networkAccessManager,SIGNAL(finished(QNetworkReply*)),this,SLOT(slotRequestFinished(QNetworkReply*)));
 
     connect(&CWptDB::self(), SIGNAL(sigChanged()), this, SLOT(slotScaleWpt2Track()));
+    connect(&CWptDB::self(), SIGNAL(sigModified(QString)), this, SLOT(slotScaleWpt2Track()));
 }
 
 
@@ -1646,8 +1646,7 @@ QString CTrack::getFocusInfo()
 void CTrack::setDoScaleWpt2Track(Qt::CheckState state)
 {
     doScaleWpt2Track = state;
-    CTrackDB::self().emitSigModified();
-    CTrackDB::self().emitSigChanged();
+    emit sigChanged();
 }
 
 
@@ -1658,7 +1657,6 @@ void CTrack::slotScaleWpt2Track()
     waypoints.clear();
     if(wptdb.count() == 0 )
     {
-        CTrackDB::self().emitSigChanged();
         return ;
     }
 
@@ -1685,15 +1683,13 @@ void CTrack::slotScaleWpt2Track()
             if(res == QMessageBox::Abort)
             {
                 doScaleWpt2Track = Qt::Unchecked;
-                CTrackDB::self().emitSigModified();
-                CTrackDB::self().emitSigChanged();
+                emit sigChanged();
                 return ;
             }
             else
             {
                 doScaleWpt2Track = Qt::Checked;
-                CTrackDB::self().emitSigModified();
-                CTrackDB::self().emitSigChanged();
+                emit sigChanged();
             }
         }
     }
@@ -1761,7 +1757,7 @@ void CTrack::slotScaleWpt2Track()
     }
 
     qSort(waypoints.begin(), waypoints.end(), qSortWptLessDistance);
-    CTrackDB::self().emitSigChanged();
+
 
     QApplication::restoreOverrideCursor();
     return ;
