@@ -2,9 +2,9 @@
     Copyright (C) 2008 Oliver Eichler oliver.eichler@gmx.de
     Copyright (C) 2010 Joerg Wunsch <j@uriah.heep.sax.de>
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,10 +13,11 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
+#include "config.h"
+
 #include <stdio.h>
 #include <limits>
 
@@ -174,7 +175,11 @@ void CTrackDB::loadGPX(CGpx& gpx)
         hasItems = true;
         CTrack* track = new CTrack(this);
                                  //preset a random color
+#if defined(HAVE_ARC4RANDOM)
+        track->setColor((arc4random() % 13)+1);
+#else
         track->setColor((rand() % 13)+1);
+#endif
 
         /*
          *  Global track information
@@ -636,11 +641,10 @@ void CTrackDB::addTrack(CTrack* track, bool silent)
     delTrack(track->getKey(), silent);
     tracks[track->getKey()] = track;
 
-    connect(track,SIGNAL(sigChanged()),SIGNAL(sigChanged()));
+    connect(track,SIGNAL(sigChanged()),this, SLOT(slotModified()));
     if(!silent)
     {
         emitSigChanged();
-        emitSigModified();
     }
 }
 
@@ -663,8 +667,7 @@ void CTrackDB::delTracks(const QStringList& keys)
     undoStack->endMacro();
     if(!keys.isEmpty())
     {
-        emitSigChanged();
-        emitSigModified();
+        emitSigChanged();        
     }
 }
 
@@ -686,16 +689,14 @@ void CTrackDB::highlightTrack(const QString& key)
 
     if(tracks.contains(key))
     {
-        tracks[key]->setHighlight(true);
-        emit sigHighlightTrack(tracks[key]);
+        CTrack * track = tracks[key];
+        track->setHighlight(true);
+        emit sigHighlightTrack(track);
     }
     else
     {
         emit sigHighlightTrack(0);
     }
-
-    emitSigChanged();
-
 }
 
 
@@ -777,7 +778,6 @@ void CTrackDB::download()
     }
 
     emitSigChanged();
-    emitSigModified();
 }
 
 
@@ -820,7 +820,6 @@ void CTrackDB::splitTrack(int idx)
     delTrack(theTrack->getKey(), true);
 
     emitSigChanged();
-    emitSigModified();
 }
 
 
@@ -1252,7 +1251,7 @@ void CTrackDB::pasteFromClipboard()
         qlb.load(&buffer);
         loadQLB(qlb, true);
 
-        emitSigModified();
+        emitSigChanged();
     }
 }
 
@@ -1264,7 +1263,6 @@ CTrack *CTrackDB::take(const QString& key, bool silent)
     if (!silent)
     {
         emitSigChanged();
-        emitSigModified();
     }
     return track;
 }
@@ -1276,19 +1274,10 @@ void CTrackDB::insert(const QString& key, CTrack *track, bool silent)
     if (!silent)
     {
         emitSigChanged();
-        emitSigModified();
     }
 }
 
 
-void CTrackDB::emitSigModified()
-{
-    IDB::emitSigModified();
-    if(highlightedTrack())
-    {
-        IDB::emitSigModified(highlightedTrack()->getKey());
-    }
-}
 
 
 void CTrackDB::revertTrack(const QString& key)
@@ -1483,6 +1472,10 @@ void CTrackDB::setPointOfFocusByIdx(qint32 idx)
     {
         emit sigPointOfFocus(idx);
     }
+    else
+    {
+        emit sigPointOfFocus(-1);
+    }
 }
 
 
@@ -1570,3 +1563,13 @@ void CTrackDB::slotMapChanged()
         track->rebuild(false);
     }
 }
+
+void CTrackDB::slotModified()
+{
+    CTrack * trk = qobject_cast<CTrack*>(sender());
+    if(trk)
+    {
+        emitSigModified(trk->getKey());
+    }
+}
+
