@@ -1,19 +1,18 @@
 /**********************************************************************************************
     Copyright (C) 2008 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-
+    
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
+    
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -184,9 +183,10 @@ CTrackEditWidget::CTrackEditWidget(QWidget * parent)
     connect(checkStages, SIGNAL(stateChanged(int)), this, SLOT(slotStagesChanged(int)));
     connect(textStages, SIGNAL(sigHighlightArea(QString)), this, SLOT(slotHighlightArea(QString)));
 
-    connect(&CTrackDB::self(), SIGNAL(sigModified()), this, SLOT(slotStagesChanged()));
+    connect(&CTrackDB::self(), SIGNAL(sigModified(const QString&)), this, SLOT(slotStagesChanged()));
     connect(&CTrackDB::self(), SIGNAL(sigPointOfFocus(int)), this, SLOT(slotPointOfFocus(int)));
-    connect(&CWptDB::self(), SIGNAL(sigModified()), this, SLOT(slotStagesChanged()));
+    connect(&CWptDB::self(),SIGNAL(sigChanged()),this,SLOT(slotStagesChanged()));
+    connect(&CWptDB::self(),SIGNAL(sigModified(QString)),this,SLOT(slotStagesChanged()));
 
     CTrackFilterWidget * w = tabWidget->findChild<CTrackFilterWidget*>();
     if(w)
@@ -843,7 +843,6 @@ void CTrackEditWidget::slotPurge()
         ++item;
     }
     track->rebuild(false);
-    CTrackDB::self().emitSigModified();
 }
 
 
@@ -1183,7 +1182,6 @@ void CTrackEditWidget::slotColorChanged(int idx)
     {
         track->setColor(comboColor->currentIndex());
         track->rebuild(true);
-        CTrackDB::self().emitSigModified();
     }
 }
 
@@ -1218,7 +1216,6 @@ void CTrackEditWidget::slotNameChanged()
     {
         track->setName(name);
         track->rebuild(true);
-        CTrackDB::self().emitSigModified();
 
         palette.setColor(QPalette::Base, QColor(128, 255, 128));
     }
@@ -1233,7 +1230,6 @@ void CTrackEditWidget::slotReset()
     track->reset();
     track->rebuild(true);
     track->slotScaleWpt2Track();
-    CTrackDB::self().emitSigModified();
 }
 
 
@@ -1268,7 +1264,6 @@ void CTrackEditWidget::slotDelete()
 
     track->rebuild(true);
     track->slotScaleWpt2Track();
-    CTrackDB::self().emitSigModified();
 }
 
 
