@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2012 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -1250,10 +1249,9 @@ void CTrackFilterWidget::postProcessTrack()
 {
     track->rebuild(true);
     track->slotScaleWpt2Track();
-
     QString key = track->getKey();
-    CTrackDB::self().emitSigModified();
     CTrackDB::self().highlightTrack(key);
+    CTrackDB::self().emitSigModified(key);
 
     trackEditWidget->slotResetAllZoom();
 }
@@ -1856,7 +1854,7 @@ bool CTrackFilterWidget::filterSplit5Tracks(QDataStream &args, QList<CTrack *> &
 
             *newTrack << trkpt;
 
-            if(trkpt == wpt->trkpt)
+            if(wpt != wpts.end() &&  trkpt == wpt->trkpt)
             {
                 wpt++;
 
