@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2010 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -33,8 +32,10 @@ CTrackStatDistanceWidget::CTrackStatDistanceWidget(QWidget * parent)
     plot->setXLabel(tr("time [h]"));
     plot->setYLabel(tr("distance [m]"));
 
-    connect(&CTrackDB::self(),SIGNAL(sigChanged()),this,SLOT(slotChanged()));
     connect(&CWptDB::self(),SIGNAL(sigChanged()),this,SLOT(slotChanged()));
+    connect(&CWptDB::self(),SIGNAL(sigModified(QString)),this,SLOT(slotChanged()));
+    connect(&CTrackDB::self(),SIGNAL(sigModified(const QString&)),this,SLOT(slotChanged()));
+    connect(&CTrackDB::self(),SIGNAL(sigChanged()),this,SLOT(slotChanged()));
     connect(&CTrackDB::self(), SIGNAL(sigHighlightTrack(CTrack*)), this, SLOT(slotSetTrack(CTrack*)));
 
     slotChanged();
@@ -53,6 +54,7 @@ CTrackStatDistanceWidget::~CTrackStatDistanceWidget()
 void CTrackStatDistanceWidget::slotSetTrack(CTrack* track)
 {
     needResetZoom = true;
+    slotChanged();
 
 }
 
