@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2008 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 #include "CTrackStatSpeedWidget.h"
@@ -39,6 +38,7 @@ CTrackStatSpeedWidget::CTrackStatSpeedWidget(type_e type, QWidget * parent)
     }
     plot->setYLabel(tr("speed [km/h]"));
 
+    connect(&CTrackDB::self(),SIGNAL(sigModified(const QString&)),this,SLOT(slotChanged()));
     connect(&CTrackDB::self(),SIGNAL(sigChanged()),this,SLOT(slotChanged()));
     connect(&CTrackDB::self(), SIGNAL(sigHighlightTrack(CTrack*)), this, SLOT(slotSetTrack(CTrack*)));
 
@@ -57,7 +57,7 @@ CTrackStatSpeedWidget::~CTrackStatSpeedWidget()
 void CTrackStatSpeedWidget::slotSetTrack(CTrack* track)
 {
     needResetZoom = true;
-
+    slotChanged();
 }
 
 
