@@ -2,19 +2,18 @@
     Copyright (C) 2007 Oliver Eichler oliver.eichler@gmx.de
     Copyright (C) 2010 Joerg Wunsch <j@uriah.heep.sax.de>
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-
+    
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
+    
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 #ifndef IDB_H
@@ -94,11 +93,9 @@ class IDB : public QObject
         static void signalsOn();
 
         virtual void emitSigChanged(){emit sigChanged(); signalFlags |= type;}
-        virtual void emitSigModified(){emit sigModified();}
         virtual void emitSigModified(const QString& key){emit sigModified(key);}
         signals:
         void sigChanged();
-        void sigModified();
         void sigModified(const QString&);
 
     protected:
