@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2007 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -52,7 +51,9 @@ IMouse::IMouse(CCanvas * canvas)
 , doSpecialCursorWpt(false)
 , doSpecialCursorSearch(false)
 , doShowWptBuddies(false)
+, lockWptCircles(false)
 {
+    rectIcon            = QRect(-8,-8,16,16);
     rectMarkWpt         = QRect(16,-8,16,16);
     rectDelWpt          = QRect(-5, 3,16,16);
     rectMoveWpt         = QRect(37, 3,16,16);
@@ -99,7 +100,6 @@ void IMouse::resizeRect(const QPoint& p, bool normalize)
 void IMouse::drawRect(QPainter& p)
 {
     p.setBrush(QBrush( QColor(230,230,255,100) ));
-    //     p.setPen(QPen(QColor(150,150,255),3));
     p.setPen(QPen(QColor(255,255,0),3));
     p.drawRect(rect);
 }
@@ -133,21 +133,229 @@ void IMouse::drawPos1(QPainter& p)
     CCanvas::drawText(fi.fileName(), p, QRect(u,v, LENGTH, 20));
 }
 
+#define RADIUS_CIRCLES      130
+#define RADIUS_CIRCLE       35
+#define ANGLE_START         -45
+void IMouse::sortSelWpts(QList<wpt_t>& list)
+{
+    struct d_t{int a[8];};
+    struct p_t{int x; int y;};
+    p_t pts[8];
+
+    int nWpts       = list.size() > 8 ? 8 : list.size();
+    d_t * dist      = new d_t[nWpts];
+    QPoint ref      = lockWptCircles ? mousePosWptCircle : mousePos;
+    int order[8]    = {-1,-1,-1,-1,-1,-1,-1,-1};
+
+    double deg = ANGLE_START;
+    for(int i = 0; i < 8; i++)
+    {
+        pts[i].x = cos(deg * DEG_TO_RAD) * RADIUS_CIRCLES;
+        pts[i].y = sin(deg * DEG_TO_RAD) * RADIUS_CIRCLES;
+        deg += 45;
+    }
+
+
+    // sort waypoints to be closest to the reference point
+    for(int i = 0; i < list.size(); i++)
+    {
+        QPoint p0       = QPoint(list[i].xReal, list[i].yReal) - ref;
+        list[i].order   = 0x7FFFFFFF;
+        list[i].dist    = p0.x()*p0.x() + p0.y()*p0.y();
+    }
+    qSort(list);
+
+
+    // calculate distance matrix for the first 8 waypoints
+    for(int i = 0; i < nWpts; i++)
+    {
+        QPoint p0       = QPoint(list[i].xReal, list[i].yReal) - ref;
+        list[i].dist    = 0x7FFFFFFF;
+        for(int j = 0; j < 8; j++)
+        {
+            dist[i].a[j] = (pts[j].x - p0.x()) * (pts[j].x - p0.x()) + (pts[j].y - p0.y()) * (pts[j].y - p0.y());
+        }
+    }
+
+    // now start the sorting hell
+    for(int i = 0; i < nWpts; i++)
+    {
+        // basically we try to find the position in the circle with the shortest distance to the waypoint
+        int minDist = 0x7FFFFFFF;
+        int minIdx  = -1;
+        for(int j = 0; j < 8; j++)
+        {
+            // if the distance is less than any seen sofar:
+            if(dist[i].a[j]  < minDist)
+            {
+                // test if this position is occupied by any other waypoint than the current one
+                if(order[j] != -1 && order[j] != i)
+                {
+                    // position conflict! who wins?
+                    if(list[order[j]].dist > dist[i].a[j])
+                    {
+                        // the current waypoints has a shorter distance than the one right now on this position
+                        minDist = dist[i].a[j];
+                        minIdx  = j;
+
+                        // we can't actually replace the waypoints now, as this is still an
+                        // intermediate result. maybe a later position is better than this
+                        // on. In this case we wouldn't like to replace the waypoint.
+                    }
+                }
+                else
+                {
+                    // trivial: position is vacant or allready occupied by current waypoint
+                    minDist = dist[i].a[j];
+                    minIdx  = j;
+                }
+            }
+        }
+
+        // finally, we have a result
+        wpt_t& wpt      = list[i];
+        wpt.dist        = minDist;
+        wpt.order       = minIdx;
+
+        // now we replace the waypoint in the order list.
+        int tmp = order[minIdx];
+        order[minIdx] = i;
+
+        // repeat the search for the waypoint that has been kicked out
+        // @todo manipulating the counter is not a good idea. better to use recursive functions
+        if(tmp != -1 && tmp != i) i = tmp - 1;
+
+    }
+
+
+
+    // convert positions to coordinates
+    for(int i = 0; i < nWpts; i++)
+    {
+        wpt_t& wpt = list[i];
+        wpt.x = pts[wpt.order].x;
+        wpt.y = pts[wpt.order].y;
+    }
+
+    qSort(list);
+
+    delete [] dist;
+}
+
 
 void IMouse::drawSelWpt(QPainter& p)
 {
-    IMap& map = CMapDB::self().getMap();
-    if(!selWpt.isNull())
+    if((selWpts.size() == 1) && !selWpts.first().wpt.isNull())
     {
-        double u = selWpt->lon * DEG_TO_RAD;
-        double v = selWpt->lat * DEG_TO_RAD;
-        map.convertRad2Pt(u,v);
+        wpt_t& wptInfo = selWpts.first();
+        drawSelWpt(p, wptInfo, eFeatAll & (~eFeatName));
+    }
+    else if(selWpts.size() > 1)
+    {
+        int idxInfoBox = -1;
+        double deg = ANGLE_START;
 
+        QPointF ref = lockWptCircles ? mousePosWptCircle : mousePos;
+
+        p.save();
+        p.translate(ref);
+
+        // draw function circles for waypoints
+        int count = selWpts.size() < 9 ? selWpts.size() : 7;
+        for(int i = 0; i < count; i++)
+        {
+            wpt_t& wptInfo = selWpts[i];
+            if(wptInfo.wpt.isNull())
+            {
+                continue;
+            }
+
+            QPoint pt = mousePos - QPoint(wptInfo.x, wptInfo.y) - mousePosWptCircle;
+            if(sqrt(pt.x()*pt.x() + pt.y()*pt.y()) < RADIUS_CIRCLE)
+            {
+                idxInfoBox = i;
+            }
+
+            p.setPen(CCanvas::penBorderBlue);
+            QPointF p0 = QPointF(wptInfo.xReal, wptInfo.yReal) - ref;
+            QPointF p1 = QPointF(wptInfo.x, wptInfo.y);
+
+            double d = sqrt((p0.x() - p1.x())*(p0.x() - p1.x()) + (p0.y() - p1.y())*(p0.y() - p1.y()));
+            double r = 40 / d;
+            double x = r * p0.x() + (1 - r) * p1.x();
+            double y = r * p0.y() + (1 - r) * p1.y();
+            p.drawLine(p0, QPointF(x,y));
+            p.drawEllipse(p0,3,3);
+
+            drawSelWpt(p, wptInfo, eFeatWheel|eFeatName);
+
+            deg += 45;
+        }
+
+        // if more than 7 waypoints display "more" message
+        if(selWpts.size() > 8)
+        {
+            int x = cos(deg * DEG_TO_RAD) * RADIUS_CIRCLES;
+            int y = sin(deg * DEG_TO_RAD) * RADIUS_CIRCLES;
+
+            p.save();
+            p.translate(x, y);
+
+            QString str = tr("too many...");
+            CCanvas::drawText(str,p,QPoint(0,0));
+
+            p.restore();
+        }
+
+        // display help box
+        {
+            QString str = tr("Left click to lock circles.\nThen select function from circle.\nLeft click on canvas to un-lock circles.");
+            QFont           f       = CResources::self().getMapFont();
+            QFontMetrics    fm(f);
+            QRect           rText   = fm.boundingRect(QRect(0,0,300,0), Qt::AlignCenter|Qt::TextWordWrap, str);
+            QRect           rFrame(0, 0, 1,1);
+
+            rFrame.setWidth(rText.width() + 20);
+            rFrame.setHeight(rText.height() + 20);
+            rText.moveTopLeft(QPoint(10, 10));
+
+            p.save();
+            p.translate(-rFrame.width()/2, RADIUS_CIRCLES + RADIUS_CIRCLE + 15);
+
+            p.setPen(CCanvas::penBorderBlue);
+            p.setBrush(CCanvas::brushBackWhite);
+            PAINT_ROUNDED_RECT(p,rFrame);
+
+            p.setFont(CResources::self().getMapFont());
+            p.setPen(Qt::darkBlue);
+            p.drawText(rText, Qt::AlignJustify|Qt::AlignCenter|Qt::TextWordWrap,str);
+            p.restore();
+        }
+
+        // display infobox for waypoint under mouse cursor, if any
+        if(idxInfoBox >= 0)
+        {
+            drawSelWpt(p, selWpts[idxInfoBox], eFeatInfoBox|eFeatArrow);
+        }
+
+        p.restore(); // mousePos
+    }
+}
+
+void IMouse::drawSelWpt(QPainter& p, wpt_t& wptInfo, quint32 features)
+{
+    CWpt * selWpt  = wptInfo.wpt;
+
+    double u = wptInfo.x;
+    double v = wptInfo.y;
+
+    if(features & eFeatWheel)
+    {
         QPixmap icon = selWpt->getIcon().scaled(16,16, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
 
         p.setPen(CCanvas::penBorderBlue);
         p.setBrush(CCanvas::brushBackWhite);
-        p.drawEllipse(u - 35, v - 35, 70, 70);
+        p.drawEllipse(u - RADIUS_CIRCLE, v - RADIUS_CIRCLE, RADIUS_CIRCLE*2, RADIUS_CIRCLE*2);
         p.drawPixmap(u - 8 , v - 8, icon);
 
         p.save();
@@ -158,7 +366,7 @@ void IMouse::drawSelWpt(QPainter& p)
             p.drawPixmap(rectDelWpt, QPixmap(":/icons/iconClear16x16.png"));
         }
 
-        if(selWpt->isMovable())
+        if(selWpt->isMovable() && (selWpts.size() == 1))
         {
             p.drawPixmap(rectMoveWpt, QPixmap(":/icons/iconMove16x16.png"));
         }
@@ -171,7 +379,7 @@ void IMouse::drawSelWpt(QPainter& p)
         p.drawPixmap(rectCopyWpt, QPixmap(":/icons/iconClipboard16x16.png"));
         if(!selWpt->images.isEmpty() /*&& !selWpt->images[0].filePath.isEmpty()*/)
         {
-            p.drawPixmap(rectViewWpt, QPixmap(":/icons/iconRaster16x16.png"));
+            p.drawPixmap(rectViewWpt, QPixmap(":/icons/iconImage16x16.png"));
         }
 
         if(selWpt->selected)
@@ -180,12 +388,15 @@ void IMouse::drawSelWpt(QPainter& p)
         }
 
         p.restore();
+    }
 
-        if(doShowWptBuddies)
-        {
-            return;
-        }
+    if(doShowWptBuddies)
+    {
+        return;
+    }
 
+    if(features & eFeatInfoBox)
+    {
         QPixmap pic;
         int wPic = 0;
         int hPic = 0;
@@ -217,7 +428,7 @@ void IMouse::drawSelWpt(QPainter& p)
         }
 
         p.save();
-        p.translate(u + 45, v);
+        p.translate(u + RADIUS_CIRCLE + 10, v);
 
         p.setPen(CCanvas::penBorderBlue);
         p.setBrush(CCanvas::brushBackWhite);
@@ -230,31 +441,77 @@ void IMouse::drawSelWpt(QPainter& p)
         if(!pic.isNull())
         {
             p.drawPixmap(10,10, pic);
+            if(selWpt->images.size() > 1)
+            {
+                p.drawPixmap(pic.width() + 10 - 16, pic.height() + 10 - 16, QPixmap("://icons/iconMultipleImages16x16.png"));
+            }
         }
 
         p.restore();
+    }
 
-        if(selWpt->dir != WPT_NOFLOAT)
-        {
+    if((selWpt->dir != WPT_NOFLOAT) && (features & eFeatArrow))
+    {
 #define ARROWDIR_H 15
 #define ARROWDIR_W 20
 
+        p.save();
+        p.setPen(CCanvas::penBorderBlue);
+        p.setBrush(CCanvas::brushBackWhite);
+
+        p.translate(u, v);
+        p.rotate(selWpt->dir);
+        p.translate(0,  - RADIUS_CIRCLE - 2 - ARROWDIR_H/2);
+
+        QPolygon arrow;
+        arrow << QPoint(0, -ARROWDIR_H/2) << QPoint(-ARROWDIR_W/2, ARROWDIR_H/2) << QPoint(0, ARROWDIR_H/3) << QPoint(ARROWDIR_W/2, ARROWDIR_H/2);
+
+        p.drawPolygon(arrow);
+
+        p.restore();
+    }
+
+    if(features & eFeatName)
+    {
+        int off;
+        p.save();
+        p.translate(u,v);
+
+        QString name = selWpt->getName();
+        QFontMetricsF fm(p.font());
+
+        off = RADIUS_CIRCLE + 4;
+        QPainterPath path(QPoint(0,-off));
+        path.arcTo(QRectF(-off,-off,off*2,off*2),90,-360);
+
+        off = RADIUS_CIRCLE + 3 + floor(fm.height()/2);
+        p.setPen(QPen(CCanvas::brushBackWhite,fm.height()));
+        p.setBrush(Qt::NoBrush);
+        p.drawEllipse(-off,-off,2*off,2*off);
+
+
+        int l = 1;
+        for ( int i = 0; i < name.size(); i++ )
+        {
+            QString str = name.mid(i,1);
+
+            qreal percent = path.percentAtLength(l);
+            QPointF point = path.pointAtPercent(percent);
+            qreal angle   = path.angleAtPercent(percent);
+
             p.save();
-            p.setPen(CCanvas::penBorderBlue);
-            p.setBrush(CCanvas::brushBackWhite);
+            p.translate(point);
+            p.rotate(-angle);
 
-            p.translate(u, v);
-            p.rotate(selWpt->dir);
-            p.translate(0,  - 37 - ARROWDIR_H/2);
-
-            QPolygon arrow;
-            arrow << QPoint(0, -ARROWDIR_H/2) << QPoint(-ARROWDIR_W/2, ARROWDIR_H/2) << QPoint(0, ARROWDIR_H/3) << QPoint(ARROWDIR_W/2, ARROWDIR_H/2);
-
-            p.drawPolygon(arrow);
+            p.setPen(CResources::self().wptTextColor());
+            p.drawText( 0, 0,str);
 
             p.restore();
-        }
 
+            l += fm.width(str) + 2;
+          }
+
+        p.restore();
     }
 }
 
@@ -270,7 +527,7 @@ void IMouse::drawSelSearch(QPainter& p)
 
         p.setPen(CCanvas::penBorderBlue);
         p.setBrush(CCanvas::brushBackWhite);
-        p.drawEllipse(u - 35, v - 35, 70, 70);
+        p.drawEllipse(u - RADIUS_CIRCLE, v - RADIUS_CIRCLE, RADIUS_CIRCLE*2, RADIUS_CIRCLE*2);
         p.drawPixmap(u-8 , v-8, QPixmap(":/icons/iconBullseye16x16"));
 
         p.save();
@@ -288,7 +545,7 @@ void IMouse::drawSelTrkPt(QPainter& p)
 {
     IMap& map       = CMapDB::self().getMap();
 
-    if(selTrkPt && !selWpt)
+    if(selTrkPt && selWpts.isEmpty())
     {
         CTrack * track = CTrackDB::self().highlightedTrack();
         if(track == 0)
@@ -361,7 +618,7 @@ void IMouse::drawSelTrkPt(QPainter& p)
 void IMouse::drawSelRtePt(QPainter& p)
 {
     IMap& map = CMapDB::self().getMap();
-    if(selRtePt && !selWpt)
+    if(selRtePt && selWpts.isEmpty())
     {
         double u = selRtePt->lon * DEG_TO_RAD;
         double v = selRtePt->lat * DEG_TO_RAD;
@@ -396,54 +653,75 @@ void IMouse::drawSelRtePt(QPainter& p)
 
 void IMouse::mouseMoveEventWpt(QMouseEvent * e)
 {
+
     QPoint pos      = e->pos();
     IMap& map       = CMapDB::self().getMap();
-    CWpt * oldWpt   = selWpt; selWpt = 0;
+    int oldSize     = selWpts.size();
 
-    // find the waypoint close to the cursor
-    QMap<QString,CWpt*>::const_iterator wpt = CWptDB::self().begin();
-    while(wpt != CWptDB::self().end())
+
+    if(!lockWptCircles)
     {
-        double u = (*wpt)->lon * DEG_TO_RAD;
-        double v = (*wpt)->lat * DEG_TO_RAD;
-        map.convertRad2Pt(u,v);
+        selWpts.clear();
 
-        if(((pos.x() - u) * (pos.x() - u) + (pos.y() - v) * (pos.y() - v)) < 1225)
+        // find the waypoint close to the cursor
+        QMap<QString,CWpt*>::const_iterator wpt = CWptDB::self().begin();
+        while(wpt != CWptDB::self().end())
         {
-            selWpt = *wpt;
-            break;
+            double u = (*wpt)->lon * DEG_TO_RAD;
+            double v = (*wpt)->lat * DEG_TO_RAD;
+            map.convertRad2Pt(u,v);
+
+            if(((pos.x() - u) * (pos.x() - u) + (pos.y() - v) * (pos.y() - v)) < 1225)
+            {
+                selWpts << wpt_t();
+
+                wpt_t& wptInfo = selWpts.last();
+                wptInfo.wpt = *wpt;
+
+                double u = wptInfo.wpt->lon * DEG_TO_RAD;
+                double v = wptInfo.wpt->lat * DEG_TO_RAD;
+                map.convertRad2Pt(u,v);
+
+                wptInfo.x = wptInfo.xReal = u;
+                wptInfo.y = wptInfo.yReal = v;
+
+            }
+
+            ++wpt;
+        }
+
+        if(selWpts.size() > 1)
+        {
+            sortSelWpts(selWpts);
         }
 
-        ++wpt;
     }
 
-    // check for cursor-over-function
-    if(selWpt)
+    // check for cursor-over-function @todo this has to be done over all waypoints
+    for(int i = 0; i < selWpts.size(); i++)
     {
-        double u = selWpt->lon * DEG_TO_RAD;
-        double v = selWpt->lat * DEG_TO_RAD;
-        map.convertRad2Pt(u,v);
+        QPoint pt;
+        wpt_t& wptInfo  = selWpts[i];
+        CWpt * selWpt   = wptInfo.wpt;
 
-        QPoint pt = pos - QPoint(u - 24, v - 24);
-
-        if(rectDelWpt.contains(pt) || rectCopyWpt.contains(pt) || rectMoveWpt.contains(pt) || rectEditWpt.contains(pt) || rectViewWpt.contains(pt))
+        if(selWpt == 0)
         {
-            if(!doSpecialCursorWpt)
-            {
-                QApplication::setOverrideCursor(Qt::PointingHandCursor);
-                doSpecialCursorWpt = true;
-            }
+            continue;
+        }
+
+
+        // mind the different offset values in wptInfo for single or multiple waypoints
+        // @todo there must be a better way
+        if(lockWptCircles)
+        {
+            pt = pos - QPoint(wptInfo.x - 24, wptInfo.y - 24) - mousePosWptCircle;
         }
         else
         {
-            if(doSpecialCursorWpt)
-            {
-                QApplication::restoreOverrideCursor();
-                doSpecialCursorWpt = false;
-            }
+            pt = pos - QPoint(wptInfo.x - 24, wptInfo.y - 24);
         }
 
-        if(selWpt->isGeoCache())
+        if(selWpt->isGeoCache() && ((selWpts.size() == 1) || lockWptCircles))
         {
             if(!doShowWptBuddies && rectMoveWpt.contains((pt)))
             {
@@ -458,27 +736,47 @@ void IMouse::mouseMoveEventWpt(QMouseEvent * e)
                 canvas->update();
             }
         }
+        else
+        {
+            selWpt->showBuddies(false);
+            doShowWptBuddies = false;
+        }
+
+        // this has to be the last thing in the loop to do, as we break if a waypoint matches
+        if(rectDelWpt.contains(pt) || rectCopyWpt.contains(pt) || rectMoveWpt.contains(pt) || rectEditWpt.contains(pt) || rectViewWpt.contains(pt))
+        {
+            if(!doSpecialCursorWpt)
+            {
+                QApplication::setOverrideCursor(Qt::PointingHandCursor);
+                doSpecialCursorWpt = true;
+            }
+            break;
+        }
+        else
+        {
+            if(doSpecialCursorWpt)
+            {
+                QApplication::restoreOverrideCursor();
+                doSpecialCursorWpt = false;
+            }
+        }
+
     }
-    else
+
+    if(selWpts.isEmpty())
     {
         if(doSpecialCursorWpt)
         {
             QApplication::restoreOverrideCursor();
             doSpecialCursorWpt = false;
         }
-
-        if(oldWpt)
-        {
-            oldWpt->showBuddies(false);
-            doShowWptBuddies = false;
-        }
     }
 
-    // do a canvas update on a change only
-    if(oldWpt != selWpt)
+    if(oldSize != selWpts.size() || selWpts.size() > 1)
     {
         canvas->update();
     }
+
 }
 
 
@@ -550,55 +848,108 @@ void IMouse::mouseMoveEventSearch(QMouseEvent * e)
 
 void IMouse::mousePressEventWpt(QMouseEvent * e)
 {
-    if(selWpt.isNull()) return;
+    if(selWpts.isEmpty()) return;
 
-    IMap& map   = CMapDB::self().getMap();
-    QPoint pos  = e->pos();
-    double u    = selWpt->lon * DEG_TO_RAD;
-    double v    = selWpt->lat * DEG_TO_RAD;
-    map.convertRad2Pt(u,v);
-
-    QPoint pt = pos - QPoint(u - 24, v - 24);
-    if(rectDelWpt.contains(pt) && !selWpt->sticky)
+    if(selWpts.size() > 1 && !lockWptCircles)
     {
-        CWptDB::self().delWpt(selWpt->getKey(), false, true);
+        lockWptCircles = true;
+        mousePosWptCircle = e->pos();
+        return;
     }
-    else if(rectMoveWpt.contains(pt) && selWpt->isMovable())
+
+    bool doBreak = false;
+    for(int i = 0; i < selWpts.size(); i++)
     {
-        canvas->setMouseMode(CCanvas::eMouseMoveWpt);
+        QPoint pt;
+        wpt_t& wptInfo  = selWpts[i];
+        CWpt * selWpt   = wptInfo.wpt;
+        QPoint pos      = e->pos();
 
-        QMouseEvent event1(QEvent::MouseMove, QPoint(u,v), Qt::NoButton, Qt::NoButton, Qt::NoModifier);
-        QCoreApplication::sendEvent(canvas,&event1);
+        if(selWpt == 0)
+        {
+            continue;
+        }
 
-        QMouseEvent event2(QEvent::MouseButtonPress, QPoint(u,v), Qt::LeftButton, Qt::NoButton, Qt::NoModifier);
-        QCoreApplication::sendEvent(canvas,&event2);
+        // mind the different offset values in wptInfo for single or multiple waypoints
+        // @todo there must be a better way
+        if(lockWptCircles)
+        {
+            pt = pos - QPoint(wptInfo.x - 24, wptInfo.y - 24) - mousePosWptCircle;
+        }
+        else
+        {
+            pt = pos - QPoint(wptInfo.x - 24, wptInfo.y - 24);
+        }
+
+        if(rectDelWpt.contains(pt) && !selWpt->sticky)
+        {
+            selWpts.removeAt(i);
+            if(selWpts.size() < 2)
+            {
+                lockWptCircles = false;
+            }
+            sortSelWpts(selWpts);
+
+            CWptDB::self().delWpt(selWpt->getKey(), false, true);
+
+            canvas->update();
+            doBreak = true;
+        }
+        else if(rectMoveWpt.contains(pt) && selWpt->isMovable() && (selWpts.size() == 1))
+        {
+            canvas->setMouseMode(CCanvas::eMouseMoveWpt);
+
+            QMouseEvent event1(QEvent::MouseMove, QPoint(wptInfo.x,wptInfo.y), Qt::NoButton, Qt::NoButton, Qt::NoModifier);
+            QCoreApplication::sendEvent(canvas,&event1);
+
+            QMouseEvent event2(QEvent::MouseButtonPress, QPoint(wptInfo.x,wptInfo.y), Qt::LeftButton, Qt::NoButton, Qt::NoModifier);
+            QCoreApplication::sendEvent(canvas,&event2);
+            doBreak = true;
+        }
+        else if(rectEditWpt.contains(pt))
+        {
+            CDlgEditWpt dlg(*selWpt,canvas);
+            dlg.exec();
+            doBreak = true;
+        }
+        else if(rectCopyWpt.contains(pt))
+        {
+            QString position;
+            GPS_Math_Deg_To_Str(selWpt->lon, selWpt->lat, position);
+
+            QClipboard *clipboard = QApplication::clipboard();
+            clipboard->setText(position);
+
+            selWpt = 0;
+            canvas->update();
+            doBreak = true;
+        }
+        else if(rectViewWpt.contains(pt) && !selWpt->images.isEmpty())
+        {
+            CImageViewer view(selWpt->images, 0, theMainWindow);
+            view.exec();
+            doBreak = true;
+        }
+        else if(rectMarkWpt.contains(pt))
+        {
+            CWptDB::self().selWptByKey(selWpt->getKey(), true);
+            canvas->update();
+            doBreak = true;
+        }
+
+        if(doBreak)
+        {
+            break;
+        }
     }
-    else if(rectEditWpt.contains(pt))
-    {
-        CDlgEditWpt dlg(*selWpt,canvas);
-        dlg.exec();
-    }
-    else if(rectCopyWpt.contains(pt))
-    {
-        QString position;
-        GPS_Math_Deg_To_Str(selWpt->lon, selWpt->lat, position);
 
-        QClipboard *clipboard = QApplication::clipboard();
-        clipboard->setText(position);
-
-        selWpt = 0;
-        canvas->update();
-    }
-    else if(rectViewWpt.contains(pt) && !selWpt->images.isEmpty() /*&& !selWpt->images[0].filePath.isEmpty()*/)
+    if(lockWptCircles && !doBreak)
     {
-        CImageViewer view(selWpt->images, 0, theMainWindow);
-        view.exec();
-    }
-    else if(rectMarkWpt.contains(pt))
-    {
-        CWptDB::self().selWptByKey(selWpt->getKey(), true);
+        lockWptCircles = false;
+        selWpts.clear();
         canvas->update();
     }
+
 }
 
 
@@ -628,7 +979,9 @@ void IMouse::mousePressEventSearch(QMouseEvent * e)
         CWpt * wpt = CWptDB::self().newWpt(selSearch->lon * DEG_TO_RAD, selSearch->lat * DEG_TO_RAD, ele, selSearch->getName());
         if(wpt)
         {
-            selWpt = wpt;
+            selWpts << wpt_t();
+            selWpts.last().wpt = wpt;
+
             QStringList keys;
 
             keys << key;
