@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2007 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -57,12 +56,12 @@ class IMouse : public QObject
         /// the mouse release event as defined by QWidget::mouseReleaseEvent
         virtual void mouseReleaseEvent(QMouseEvent * e) = 0;
         /// the mouse double click event as defined by QWidget::mouseDoubleClickEvent
-        virtual void mouseDoubleClickEvent(QMouseEvent * e){};
+        virtual void mouseDoubleClickEvent(QMouseEvent * e){}
 
         /// the key press event as defined by QWidget::keyPressEvent
-        virtual void keyPressEvent(QKeyEvent *) {};
+        virtual void keyPressEvent(QKeyEvent *) {}
         /// the key release event as defined by QWidget::keyPressEvent
-        virtual void keyReleaseEvent(QKeyEvent *) {};
+        virtual void keyReleaseEvent(QKeyEvent *) {}
 
         /// the current mouse cursor
         /**
@@ -92,10 +91,42 @@ class IMouse : public QObject
 #ifdef GPX_EXTENSIONS
         CGpxExtTr tr_ext;        //TODO: CGpxExtPt -> tr_ext
 #endif
+
     protected slots:
         void slotSetPos1();
 
     protected:
+        enum features_e
+        {
+             eFeatInfoBox = 0x00000001
+            ,eFeatArrow   = 0x00000002
+            ,eFeatWheel   = 0x00000004
+            ,eFeatName    = 0x00000008
+            ,eFeatAll     = 0xFFFFFFFF
+        };
+
+        struct wpt_t
+        {
+            wpt_t(): x(0), y(0), order(0x7FFFFFFF), dist(0x7FFFFFFF){}
+
+            bool operator<(const wpt_t& w) const
+            {
+                if(order == w.order)
+                {
+                    return dist < w.dist;
+                }
+                return order < w.order;
+            }
+
+            QPointer<CWpt> wpt;
+            int x;
+            int y;
+            int xReal;
+            int yReal;
+            int order;
+            int dist;
+        };
+
         /// for internal use to start a semi-transparent capture rectangle
         void startRect(const QPoint& p);
         /// for internal use to set the bottom right of the capture rectangle
@@ -104,6 +135,8 @@ class IMouse : public QObject
         void drawRect(QPainter& p);
         /// draw selected waypoint
         void drawSelWpt(QPainter& p);
+        void drawSelWpt(QPainter& p, wpt_t& wptInfo, quint32 features);
+
         /// draw selected track point
         void drawSelTrkPt(QPainter& p);
         /// draw selected route point
@@ -126,6 +159,8 @@ class IMouse : public QObject
         ///
         void mouseMoveEventMapSel(QMouseEvent * e);
 
+        void sortSelWpts(QList<wpt_t>& list);
+
         /// trigger waypoint function
         void mousePressEventWpt(QMouseEvent * e);
         /// trigger search function
@@ -138,7 +173,8 @@ class IMouse : public QObject
         QRect rect;
 
         /// current selected waypoint
-        QPointer<CWpt> selWpt;
+        QList<wpt_t> selWpts;
+
         /// current selected trackpoint
         CTrack::pt_t * selTrkPt;
         /// current selected routepoint
@@ -150,6 +186,7 @@ class IMouse : public QObject
 
         QPointer<CSearch> selSearch;
 
+        QRect rectIcon;
         QRect rectMarkWpt;
         QRect rectDelWpt;
         QRect rectMoveWpt;
@@ -163,17 +200,14 @@ class IMouse : public QObject
 
         bool doSpecialCursorWpt;
         bool doSpecialCursorSearch;
-
         bool doShowWptBuddies;
+        bool lockWptCircles;
 
         QPoint lastPoint;
         QPoint mousePos;
+        QPoint mousePosWptCircle;
 
         static QPointF pos1Pixel;
         static QPointF pos1LonLat;
-
-#ifdef GPX_EXTENSIONS
-        //QPointer<CTrack> track;  //TODO: noch ne def
-#endif
 };
 #endif                           //IMOUSE_H
